@@ -2,9 +2,8 @@ import inspect
 import io
 import os
 import re
-from pdb import Pdb
+from pdb import Pdb, getsourcelines
 
-from icecream import ic
 from rich import box
 from rich._inspect import Inspect
 from rich.console import Console
@@ -16,7 +15,7 @@ from rich.text import Text
 from rich.theme import Theme
 from rich.tree import Tree
 
-from pdbr.console_layout import ConsoleLayout
+from pdbr._console_layout import ConsoleLayout
 
 try:
     from IPython.terminal.interactiveshell import TerminalInteractiveShell
@@ -42,6 +41,7 @@ def rich_pdb_klass(base, is_celery=False, context=None, show_layouts=True):
         _theme = None
         _history_file = None
         _ipython_history_file = None
+        _latest_search_arg = ""
 
         def __init__(
             self,
@@ -97,6 +97,8 @@ def rich_pdb_klass(base, is_celery=False, context=None, show_layouts=True):
                         {"info": "dim cyan", "warning": "magenta", "danger": "bold red"}
                     ),
                     style=self._style,
+                    force_terminal=True,
+                    force_interactive=True,
                 )
             return self._console
 
@@ -167,6 +169,34 @@ def rich_pdb_klass(base, is_celery=False, context=None, show_layouts=True):
 
         do_ll = do_longlist
 
+        def do_search(self, arg):
+            """search | src
+            Search a phrase in the current frame.
+            In order to repeat the last one, type `/` character as arg.
+            """
+            if not arg or (arg == "/" and not self._latest_search_arg):
+                self.error("Search failed: arg is missing")
+                return
+
+            if arg == "/":
+                arg = self._latest_search_arg
+            else:
+                self._latest_search_arg = arg
+
+            lines, lineno = getsourcelines(self.curframe)
+            indexes = [index for index, line in enumerate(lines, lineno) if arg in line]
+
+            if len(indexes) > 0:
+                bigger_indexes = [
+                    index for index in indexes if index > self.curframe.f_lineno
+                ]
+                next_line = bigger_indexes[0] if bigger_indexes else indexes[0]
+                return super().do_jump(next_line)
+            else:
+                self.error(f"Search failed: '{arg}' not found")
+
+        do_src = do_search
+
         def get_varstable(self):
             variables = self._get_variables()
             if not variables:
@@ -254,6 +284,8 @@ def rich_pdb_klass(base, is_celery=False, context=None, show_layouts=True):
             Icecream print.
             """
             try:
+                from icecream import ic
+
                 val = self._getval(arg)
                 ic.configureOutput(prefix="🍦 |> ")
                 self._print(ic.format(arg, val))
@@ -315,7 +347,7 @@ def rich_pdb_klass(base, is_celery=False, context=None, show_layouts=True):
         def _print_layout(self, val, **kwargs):
             ConsoleLayout(self.console).print(
                 val,
-                code=self._get_syntax_for_list(with_line_range=True),
+                code=self._get_syntax_for_list(),
                 stack_trace=self.stack_trace(**kwargs),
                 vars=self.get_varstree(),
                 **kwargs,
